<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="application-name" content="PYPI"/>

    <meta name="fragment" content="!">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
    <meta http-equiv="X-UA-Compatible" content="IE=Edge"/>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no"/>

    <link rel="apple-touch-icon-precomposed" sizes="57x57" href="/static/favicon/apple-touch-icon-57x57.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="/static/favicon/apple-touch-icon-114x114.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="/static/favicon/apple-touch-icon-72x72.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="/static/favicon/apple-touch-icon-144x144.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="60x60" href="/static/favicon/apple-touch-icon-60x60.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="120x120" href="/static/favicon/apple-touch-icon-120x120.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="76x76" href="/static/favicon/apple-touch-icon-76x76.png"/>
    <link rel="apple-touch-icon-precomposed" sizes="152x152" href="/static/favicon/apple-touch-icon-152x152.png"/>
    <link rel="icon" type="image/png" href="/static/favicon/favicon-32x32.png" sizes="32x32"/>
    <link rel="icon" type="image/png" href="/static/favicon/favicon-16x16.png" sizes="16x16"/>

    <meta name="msapplication-TileColor" content="#FFFFFF"/>
    <meta name="msapplication-TileImage" content="/static/favicon/mstile-144x144.png"/>

    {% for item in vendor_css %}
    <link rel="stylesheet" href="{{ item }}"/>{% end %}

    {% for item in styles %}
    <link rel="stylesheet" href="{{ item }}"/>{% end %}

    {% for lib in vendor_js %}
    <script type="application/javascript" src="{{ lib }}"></script>{% end %}

    {% for lib in application %}
    <script type="application/javascript" src="{{ lib }}"></script>{% end %}

    <title>PYPI server</title>
</head>

<body ng-app="PYPI">

<div ng-controller="indexCtrl">
    <div id="loader" ng-show="!$root.loader.toBool()">
        <div class="spinner"></div>
    </div>
</div>

<nav class="navbar navbar-inverse">
    <div class="container-fluid">
        <!-- Brand and toggle get grouped for better mobile display -->
        <div class="navbar-header">
            <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
            <a class="navbar-brand" href="">
                <img alt="Brand" height="80%" src="/static/favicon/apple-touch-icon-72x72.png">
            </a>
        </div>

        <!-- Collect the nav links, forms, and other content for toggling -->
        <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
            <ul class="nav navbar-nav" ng-controller="navigationCtrl">
                <li ng-repeat="item in navigation track by $index" ng-class="{active: isActive(item)}">
                    <a ng-href="/#{{! item.href }}"><span ng-bind="item.name"></span></a>
                </li>
            </ul>
            <ul class="nav navbar-nav navbar-right">
                <form class="navbar-form navbar-left" role="search">
                    <div class="form-group">
                        <input type="text" class="form-control" placeholder="Search" ng-model="$root.search">
                    </div>
                </form>
            </ul>
        </div><!-- /.navbar-collapse -->
    </div><!-- /.container-fluid -->
</nav>


<div class="col-md-12 content" ng-view></div>

{% include "templates.html" %}

</body>
</html>